//                                                                  
// Copyright  2013 Lidor Systems.
// All Rights Reserved.
//
// This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
// either express or implied. 
//

using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.IO;
using System.Text;
using System.Windows.Forms;

namespace IUTC_CloseButton
{
    public partial class Form1 : Form
    {
        #region Variables
        private const String referencePath = "../../../Demo/";
        #endregion

        #region Initialization
        public Form1()
        {
            InitializeComponent();

            CreateLabelContent();
        }

        private void CreateLabelContent()
        {
            String content = "<div style=\"font:Verdana,9,r\"><p>   In this sample we are showing how to create add a close button to each tab header.</p><br></br>";
            content += "<p>   By default all tabs are using the same set of command buttons from its parent TabControl. However, each tab can also have its own specific set of command buttons. By clicking on 'Add Close Button', we will see how a command buttons is added to the selected tab. If we click on 'Use Parent Buttons' we can see how all tabs now contain the same button.</p><br></br>";
            content += "<p>   To handle clicks from command buttons we are using the <b>TabButtonClicked</b> event where we handle what action is processed when button is clicked. See the source code form more information.</p><br></br>";
            content += "<p><table width=\"100%\" cellpadding=\"5\"><tr height=\"5\"></tr>";
            content += "<tr><td width=\"70%\" style=\"textcolor:DarkRed;hovertextcolor:Red\"><a href=\"QuickStart.exe\" id=\"FILE\">Quick Start</a></td>";
            content += "<td width=\"30%\" style=\"align:middleright;textcolor:DarkRed;hovertextcolor:Red\"><a href=\"www.lidorsystems.com/support/articles/winforms/tabcontrol/\">More Info ...</a></td></tr></table></p>";
            content += "</div>";

            this.labelInfo.Content = content;
        }

        private void labelInfo_ContentObjectClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            if (e.Object is LinkLabel)
            {
                String relativePath = (e.Object as LinkLabel).Links[0].LinkData.ToString();

                if (e.Key == "FILE")
                {
                    String appPath = Path.GetFullPath(Path.Combine(referencePath, relativePath));
                    if (File.Exists(appPath))
                        System.Diagnostics.Process.Start(appPath);
                    else if (File.Exists(relativePath))
                        System.Diagnostics.Process.Start(relativePath);
                }
                else
                    System.Diagnostics.Process.Start(relativePath);
            }
        }
        #endregion

        #region Functionality
        private void btnAddClose_Click(object sender, EventArgs e)
        {
            // Check whether there is some tab on top (selected)
            if (this.tabControl1.SelectedPage != null)
            {
                // Create a command button
                // Set the ImageIndex property to show the first image from the list
                // Set the Key property to TAB_CLOSE, so we can identify what kind of a button was clicked
                LidorSystems.IntegralUI.Controls.CommandButton closeButton = new LidorSystems.IntegralUI.Controls.CommandButton();
                closeButton.ImageIndex = 0;
                closeButton.Key = "TAB_CLOSE";

                // In this demo we are using only one command button
                // If the button collection is empty, add the close button to it
                if (this.tabControl1.SelectedPage.Buttons.Count == 0)
                    this.tabControl1.SelectedPage.Buttons.Add(closeButton);
                this.tabControl1.SelectedPage.UseParentButtons = false;

                // Update the control layout to apply changes
                this.tabControl1.UpdateLayout();
            }
        }

        private void tabControl1_TabButtonClicked(object sender, LidorSystems.IntegralUI.ObjectClickEventArgs e)
        {
            // Check whether the opbject carried with the event is a command button
            if (e.Object is LidorSystems.IntegralUI.Controls.CommandButton)
            {
                LidorSystems.IntegralUI.Controls.CommandButton btn = (LidorSystems.IntegralUI.Controls.CommandButton)e.Object;

                // Check whether the type of a button is a close button
                if (btn.Key == "TAB_CLOSE")
                {
                    // Locate the tab in which the command button was clicked
                    LidorSystems.IntegralUI.Containers.TabPage page = this.tabControl1.GetPageAt(e.Position);

                    if (page != null)
                    {
                        // Depending on the action, you can determine whether you want to hide or dispose the tab
                        switch (this.tabControl1.CloseAction)
                        {
                            case LidorSystems.IntegralUI.CloseAction.Hide:
                                page.Hide();
                                break;

                            default:
                                page.Remove();
                                break;
                        }
                    }
                }
            }
        }

        private void btnParentButtons_Click(object sender, EventArgs e)
        {
            // Make sure all tabs use command buttons from its parent TabControl
            foreach (LidorSystems.IntegralUI.Containers.TabPage page in this.tabControl1.Pages)
                page.UseParentButtons = true;

            // Create a command button
            // Set the ImageIndex property to show the second image from the list
            // Set the Key property to TAB_CLOSE, so we can identify what kind of a button was clicked
            LidorSystems.IntegralUI.Controls.CommandButton closeButton = new LidorSystems.IntegralUI.Controls.CommandButton();
            closeButton.ImageIndex = 1;
            closeButton.Key = "TAB_CLOSE";

            // In this demo we are using only one command button
            // If the button collection is empty, add the close button to it
            if (this.tabControl1.TabButtons.Count == 0)
                this.tabControl1.TabButtons.Add(closeButton);
        }

        private void btnReset_Click(object sender, EventArgs e)
        {
            this.tabControl1.Pages.Clear();
            this.tabControl1.TabButtons.Clear();

            for (int i = 1; i <= 3; i++)
                this.tabControl1.Pages.Add("tabPage" + i.ToString());
        }
        #endregion
    }
}