'                                                                  
' Copyright  2013 Lidor Systems.
' All Rights Reserved.
'
' This SOFTWARE is provided "AS IS", WITHOUT WARRANTY OF ANY KIND.
' either express or implied. 
'

Imports System.IO

Public Class Form1

#Region "Variables"
    Private Const referencePath As [String] = "../../../Demo/"
#End Region

#Region "Initialization"
    Public Sub New()
        InitializeComponent()

        CreateLabelContent()
    End Sub

    Private Sub CreateLabelContent()
        Dim content As [String] = "<div style=""font:Verdana,9,r""><p>   In this sample we are showing how to create add a close button to each tab header.</p><br></br>"
        content += "<p>   By default all tabs are using the same set of command buttons from its parent TabControl. However, each tab can also have its own specific set of command buttons. By clicking on 'Add Close Button', we will see how a command buttons is added to the selected tab. If we click on 'Use Parent Buttons' we can see how all tabs now contain the same button.</p><br></br>"
        content += "<p>   To handle clicks from command buttons we are using the <b>TabButtonClicked</b> event where we handle what action is processed when button is clicked. See the source code form more information.</p><br></br>"
        content += "<p><table width=""100%"" cellpadding=""5""><tr height=""5""></tr>"
        content += "<tr><td width=""70%"" style=""textcolor:DarkRed;hovertextcolor:Red""><a href=""QuickStart.exe"" id=""FILE"">Quick Start</a></td>"
        content += "<td width=""30%"" style=""align:middleright;textcolor:DarkRed;hovertextcolor:Red""><a href=""www.lidorsystems.com/support/articles/winforms/tabcontrol/"">More Info ...</a></td></tr></table></p>"
        content += "</div>"

        Me.labelInfo.Content = content
    End Sub

    Private Sub labelInfo_ContentObjectClicked(ByVal sender As Object, ByVal e As LidorSystems.IntegralUI.ObjectClickEventArgs) Handles labelInfo.ContentObjectClicked
        If TypeOf e.[Object] Is LinkLabel Then
            Dim relativePath As [String] = TryCast(e.[Object], LinkLabel).Links(0).LinkData.ToString()

            If e.Key = "FILE" Then
                Dim appPath As [String] = Path.GetFullPath(Path.Combine(referencePath, relativePath))
                If File.Exists(appPath) Then
                    System.Diagnostics.Process.Start(appPath)
                ElseIf File.Exists(relativePath) Then
                    System.Diagnostics.Process.Start(relativePath)
                End If
            Else
                System.Diagnostics.Process.Start(relativePath)

            End If
        End If
    End Sub
#End Region

#Region "Functionality"
    Private Sub btnAddClose_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnAddClose.Click
        ' Check whether there is some tab on top (selected)
        If Me.tabControl1.SelectedPage IsNot Nothing Then
            ' Create a command button
            ' Set the ImageIndex property to show the first image from the list
            ' Set the Key property to TAB_CLOSE, so we can identify what kind of a button was clicked
            Dim closeButton As New LidorSystems.IntegralUI.Controls.CommandButton()
            closeButton.ImageIndex = 0
            closeButton.Key = "TAB_CLOSE"

            ' In this demo we are using only one command button
            ' If the button collection is empty, add the close button to it
            If Me.tabControl1.SelectedPage.Buttons.Count = 0 Then
                Me.tabControl1.SelectedPage.Buttons.Add(closeButton)
            End If
            Me.tabControl1.SelectedPage.UseParentButtons = False

            ' Update the control layout to apply changes
            Me.tabControl1.UpdateLayout()
        End If
    End Sub

    Private Sub tabControl1_TabButtonClicked(ByVal sender As Object, ByVal e As LidorSystems.IntegralUI.ObjectClickEventArgs) Handles tabControl1.TabButtonClicked
        ' Check whether the opbject carried with the event is a command button
        If TypeOf e.[Object] Is LidorSystems.IntegralUI.Controls.CommandButton Then
            Dim btn As LidorSystems.IntegralUI.Controls.CommandButton = DirectCast(e.[Object], LidorSystems.IntegralUI.Controls.CommandButton)

            ' Check whether the type of a button is a close button
            If btn.Key = "TAB_CLOSE" Then
                ' Locate the tab in which the command button was clicked
                Dim page As LidorSystems.IntegralUI.Containers.TabPage = Me.tabControl1.GetPageAt(e.Position)

                If page IsNot Nothing Then
                    ' Depending on the action, you can determine whether you want to hide or dispose the tab
                    Select Case Me.tabControl1.CloseAction
                        Case LidorSystems.IntegralUI.CloseAction.Hide
                            page.Hide()
                            Exit Select
                        Case Else

                            page.Remove()
                            Exit Select
                    End Select
                End If
            End If
        End If
    End Sub

    Private Sub btnParentButtons_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnParentButtons.Click
        ' Make sure all tabs use command buttons from its parent TabControl
        For Each page As LidorSystems.IntegralUI.Containers.TabPage In Me.tabControl1.Pages
            page.UseParentButtons = True
        Next

        ' Create a command button
        ' Set the ImageIndex property to show the second image from the list
        ' Set the Key property to TAB_CLOSE, so we can identify what kind of a button was clicked
        Dim closeButton As New LidorSystems.IntegralUI.Controls.CommandButton()
        closeButton.ImageIndex = 1
        closeButton.Key = "TAB_CLOSE"

        ' In this demo we are using only one command button
        ' If the button collection is empty, add the close button to it
        If Me.tabControl1.TabButtons.Count = 0 Then
            Me.tabControl1.TabButtons.Add(closeButton)
        End If
    End Sub

    Private Sub btnReset_Click(ByVal sender As Object, ByVal e As EventArgs) Handles btnReset.Click
        Me.tabControl1.Pages.Clear()
        Me.tabControl1.TabButtons.Clear()

        For i As Integer = 1 To 3
            Me.tabControl1.Pages.Add("tabPage" & i.ToString())
        Next
    End Sub
#End Region

End Class
